@@ -14,25 +14,17 @@ Fl_Widget* WidgetVec::at(size_t idx) { return buf[idx]; }
 
 Fl_Widget* WidgetVec::operator[](size_t idx) { return at(idx); }
 
-void WidgetVec::reserve(size_t sz)
-{
-    if (buf == 0) {
-        len = 0;
-        cap = 0;
-    }
-    Fl_Widget** new_buf = new Fl_Widget*[sz];
-    memcpy(new_buf, buf, sz);
-    cap = sz;
-    delete[] buf;
-    buf = new_buf;
-}
-
 void WidgetVec::push_back(Fl_Widget* w)
 {
-    if (len >= cap) {
-        reserve(cap * 2);
+    if (len == cap) {
+        cap = cap * 2;
+        Fl_Widget** new_buf = new Fl_Widget*[cap];
+        for (size_t i = 0; i < len; i++) new_buf[i] = buf[i];
+        delete[] buf;
+        buf = new_buf;
     }
-    buf[len++] = w;
+    buf[len] = w;
+    len++;
 }
 
 WidgetVec::~WidgetVec()
@@ -44,7 +36,6 @@ bool Fl_Flex::_debug = false;
 
 Fl_Flex::Fl_Flex(uchar direction)
     : Fl_Group(0, 0, 0, 0, 0)
-    , setsized(WidgetVec {})
 {
     type(direction);
     debug();
@@ -52,7 +43,6 @@ Fl_Flex::Fl_Flex(uchar direction)
 
 Fl_Flex::Fl_Flex(int w, int h, uchar direction)
     : Fl_Group(0, 0, w, h, 0)
-    , setsized(WidgetVec {})
 {
     type(direction);
     debug();
@@ -60,7 +50,6 @@ Fl_Flex::Fl_Flex(int w, int h, uchar direction)
 
 Fl_Flex::Fl_Flex(int x, int y, int w, int h, uchar direction)
     : Fl_Group(x, y, w, h, 0)
-    , setsized(WidgetVec {})
 {
     type(direction);
     debug();
@@ -68,7 +57,6 @@ Fl_Flex::Fl_Flex(int x, int y, int w, int h, uchar direction)
 
 Fl_Flex::Fl_Flex(int x, int y, int w, int h, const char* label)
     : Fl_Group(x, y, w, h, label)
-    , setsized(WidgetVec {})
 {
     type(ROW);
     debug();
