@@ -79,6 +79,18 @@ int Fl_screen_h(void);
 
 int Fl_screen_w(void);
 
+int Fl_compose(int *del);
+
+void Fl_compose_reset(void);
+
+int Fl_compose_state(void);
+
+void Fl_reset_marked_text(void);
+
+void Fl_insertion_point_location(int x, int y, int height);
+
+void Fl_copy(const char *stuff, int len, int destination);
+
 void Fl_paste_text(Fl_Widget *, int src);
 
 void Fl_paste_image(Fl_Widget *widget, int src);
@@ -121,6 +133,8 @@ void Fl_set_font2(int, const char *);
 
 void Fl_set_font_size(int);
 
+int Fl_font_size(void);
+
 void Fl_add_handler(int (*ev_handler)(int ev));
 
 void Fl_awake_msg(void *msg);
@@ -295,6 +309,10 @@ void Fl_remove_system_handler(int (*)(void *, void *));
 
 int Fl_gl_visual(int mode);
 
+void Fl_add_clipboard_notify(void (*cb)(int source, void *data), void *data);
+
+void Fl_remove_clipboard_notify(void (*cb)(int source, void *data));
+
 #ifdef __cplusplus
 }
 #endif
